<?php

namespace Drupal\connectid;

use ConnectId\Api\DataModel\CouponType;
use ConnectId\Api\DataModel\CouponTypeList;
use ConnectId\Api\DataModel\Order;
use ConnectId\Api\DataModel\OrderStatus;
use ConnectId\Api\DataModel\ProductTypeList;
use ConnectId\Api\DataModel\SubscriptionList;
use Drupal\Core\Url;
use League\OAuth2\Client\Token\AccessToken;
use League\OAuth2\Client\Token\AccessTokenInterface;
use ConnectId\OAuth2\Client\Provider\ConnectId;

/**
 * Interface ApiServiceInterface.
 */
interface ApiServiceInterface {

  /**
   * Gets a configured instance of the ConnectID client.
   *
   * @return \ConnectId\OAuth2\Client\Provider\ConnectId
   */
  public function getOauthClient(): ConnectId;

  /**
   * Lists the Products.
   *
   * @see https://doc.mediaconnect.no/doc/ConnectID/#tag/Product/paths/~1v1~1customer~1product/get
   *
   * @return \ConnectId\Api\DataModel\ProductTypeList
   */
  public function getProducts(): ProductTypeList;

  /**
   * Lists the coupons for a given product.
   *
   * @see https://doc.mediaconnect.no/doc/ConnectID/#tag/Coupon/paths/~1v1~1client~1coupon~1{productId}/get
   *
   * @param string $productName
   *
   * @return \ConnectId\Api\DataModel\CouponTypeList
   */
  public function getProductCoupons(string $productName): CouponTypeList;

  public function getCoupon(string $couponId): ?CouponType;

  public function registerOrder(AccessTokenInterface $token, Order $order): Order;

  public function registerOrderClientMode(Order $order): Order;

  public function getOrderFulfillmentUrl(Order $order, Url $successUrl = NULL, Url $errorUrl = NULL): Url;

  public function getOrderStatus(string $orderId): ?OrderStatus;

  public function getUserSubscriptions(AccessTokenInterface $token): SubscriptionList;
}
